@@ -1,5 +1,5 @@
 /* GKrellM
-|  Copyright (C) 1999-2010 Bill Wilson
+|  Copyright (C) 1999-2014 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
@@ -437,7 +437,7 @@ void	gkrellm_remove_plugin_config_page(GkrellmMonitor *);
 void	gkrellm_set_theme_alternatives_label(void);
 void	gkrellm_start_timer(gint);
 
-GtkItemFactory *gkrellm_create_item_factory_popup(void);
+GtkUIManager *gkrellm_create_ui_manager_popup(void);
 
 void	gkrellm_apply_hostname_config(void);
 gboolean gkrellm_hostname_can_shorten(void);
@@ -475,7 +475,7 @@ gint		gkrellm_sensor_read_voltage(gpointer sr, gfloat *);
 GkrellmAlert *gkrellm_sensor_alert(gpointer sr);
 void		gkrellm_sensor_alert_connect(gpointer sr,
 						void (*fn)(), gpointer data);
-void		gkrellm_sensor_reset_location(gpointer sr);
+gboolean	gkrellm_sensor_reset_location(gpointer sr);
 void		gkrellm_sensors_rebuild(gboolean do_temp, gboolean do_fan,
 						gboolean do_volt);
 void		gkrellm_sensors_model_update(void);
@@ -513,5 +513,4 @@ enum GkrellmConnectState
 			gkrellm_client_server_connect_state(void);
 void		gkrellm_client_mode_connect_thread(void);
 gint		gkrellm_client_server_get_net_timer(void);
-
-
+guint		big_endian_uint(guint8 *b);
